==> dcoupon_sdk_flutter_package-1.0.4.tar.gz: test/dcoupon_sdk_flutter_plugin_test.dart <==
import 'dart:io';

import 'package:dcoupon_sdk_flutter_package/dcoupon_sdk_flutter_package.dart';
import 'package:flutter_test/flutter_test.dart';

void main() {
  TestWidgetsFlutterBinding.ensureInitialized();
  Dcoupon dcoupon;

  setUp(() {
    dcoupon = new Dcoupon();
    dcoupon.loadConfig(new File('test.json').readAsStringSync());
    /*dcoupon.setJwt("mocked_jwt");
    dcoupon.setClientType("mocked_clientType");
    dcoupon.setIsLogged(true);*/
  });

  tearDown(() {});

  test('login', () async {
    dcoupon
        .logIn('mocked@mocked.com', 'mocked',
            alias: 'mocked', gender: 'mocked', birthdate: 'YYYY-MM-dd')
        .then((response) {
      expect(response.code, 400);
    }).catchError((ex) {
      print(ex.toString());
    });
  });

  test('getCoupons', () async {
    dcoupon.getCoupons(offset: 0, limit: 0, sortBy: null).then((response) {
      expect(response.code, 400);
    }).catchError((ex) {
      print(ex.toString());
    });
  });

  test('getCouponDetail', () async {
    dcoupon.getCouponDetail(0).then((response) {
      expect(response.code, 400);
    }).catchError((ex) {
      print(ex.toString());
    });
  });

  test('activateCoupon', () async {
    dcoupon.activateCoupon(0).then((response) {
      expect(response.code, 400);
    }).catchError((ex) {
      print(ex.toString());
    });
  });

  test('deactivateCoupon', () async {
    dcoupon.deactivateCoupon(0).then((response) {
      expect(response.code, 400);
    }).catchError((ex) {
      print(ex.toString());
    });
  });
  test('getRedemptionCode', () async {
    dcoupon.getRedemptionCode().then((response) {
      expect(response.code, 400);
    }).catchError((ex) {
      print(ex.toString());
    });
  });

  test('createCoupons', () async {
    dcoupon.createCoupons(['mocked', 'mocked'],
        latitude: null,
        longitude: null,
        source: null,
        transId: null,
        crmId: null).then((response) {
      expect(response.code, 400);
    }).catchError((ex) {
      print(ex.toString());
    });
  });

  test('getCategories', () async {
    dcoupon.getCategories(start: 0, limit: 0).then((response) {
      expect(response.code, 400);
    }).catchError((ex) {
      print(ex.toString());
    });
  });

  test('getPromotions', () async {
    dcoupon
        .getPromotions(
            start: 0,
            limit: 0,
            categoryIds: null,
            storeIds: null,
            retailerTokens: null,
            companyTokens: null,
            textSearch: null,
            zipcode: null,
            latitude: null,
            longitude: null,
            radius: null,
            orderBy: null)
        .then((response) {
      expect(response.code, 400);
    }).catchError((ex) {
      print(ex.toString());
    });
  });

  test('getPromotionDetail', () async {
    dcoupon.getPromotionDetail(null).then((response) {
      expect(response.code, 400);
    }).catchError((ex) {
      print(ex.toString());
    });
  });

  test('getStores', () async {
    dcoupon
        .getStores(
            start: 0,
            limit: 0,
            promotionToken: null,
            retailerTokens: null,
            zipcode: null,
            latitude: null,
            longitude: null,
            radius: null)
        .then((response) {
      expect(response.code, 400);
    }).catchError((ex) {
      print(ex.toString());
    });
  });

  testWidgets("Empty widget test", (tester) async {});
}

==> dcoupon_sdk_flutter_package-1.1.3.tar.gz: test/dcoupon_sdk_flutter_plugin_test.dart <==
import 'dart:io';

import 'package:dcoupon_sdk_flutter_package/dcoupon_sdk_flutter_package.dart';
import 'package:flutter_test/flutter_test.dart';

void main() {
  TestWidgetsFlutterBinding.ensureInitialized();
  Dcoupon dcoupon;

  setUp(() {
    dcoupon = new Dcoupon();
    dcoupon.loadConfig(new File('test.json').readAsStringSync());
    /*dcoupon.setJwt("mocked_jwt");
    dcoupon.setClientType("mocked_clientType");
    dcoupon.setIsLogged(true);*/
  });

  tearDown(() {});

  test('login', () async {
    dcoupon
        .logIn('mocked@mocked.com', 'mocked',
            alias: 'mocked', gender: 'mocked', birthdate: 'YYYY-MM-dd')
        .then((response) {
      expect(response.code, 400);
    }).catchError((ex) {
      print(ex.toString());
    });
  });

  test('getCoupons', () async {
    dcoupon.getCoupons(offset: 0, limit: 0, sortBy: null).then((response) {
      expect(response.code, 400);
    }).catchError((ex) {
      print(ex.toString());
    });
  });

  test('getCouponDetail', () async {
    dcoupon.getCouponDetail(0).then((response) {
      expect(response.code, 400);
    }).catchError((ex) {
      print(ex.toString());
    });
  });

  test('activateCoupon', () async {
    dcoupon.activateCoupon(0).then((response) {
      expect(response.code, 400);
    }).catchError((ex) {
      print(ex.toString());
    });
  });

  test('deactivateCoupon', () async {
    dcoupon.deactivateCoupon(0).then((response) {
      expect(response.code, 400);
    }).catchError((ex) {
      print(ex.toString());
    });
  });
  test('getRedemptionCode', () async {
    dcoupon.getRedemptionCode().then((response) {
      expect(response.code, 400);
    }).catchError((ex) {
      print(ex.toString());
    });
  });

  test('createCoupons', () async {
    dcoupon.createCoupons(['mocked', 'mocked'],
        latitude: null,
        longitude: null,
        source: null,
        transId: null,
        crmId: null).then((response) {
      expect(response.code, 400);
    }).catchError((ex) {
      print(ex.toString());
    });
  });

  test('getCategories', () async {
    dcoupon.getCategories().then((response) {
      expect(response.code, 400);
    }).catchError((ex) {
      print(ex.toString());
    });
  });

  test('getPromotions', () async {
    dcoupon
        .getPromotions(
            start: 0,
            limit: 0,
            categoryIds: null,
            storeIds: null,
            retailerTokens: null,
            companyTokens: null,
            textSearch: null,
            zipcode: null,
            latitude: null,
            longitude: null,
            radius: null,
            orderBy: null)
        .then((response) {
      expect(response.code, 400);
    }).catchError((ex) {
      print(ex.toString());
    });
  });

  test('getPromotionDetail', () async {
    dcoupon.getPromotionDetail(null).then((response) {
      expect(response.code, 400);
    }).catchError((ex) {
      print(ex.toString());
    });
  });

  test('getStores', () async {
    dcoupon
        .getStores(
            null,
            start: 0,
            limit: 0,
            retailerTokens: null,
            zipcode: null,
            latitude: null,
            longitude: null,
            radius: null)
        .then((response) {
      expect(response.code, 400);
    }).catchError((ex) {
      print(ex.toString());
    });
  });

  testWidgets("Empty widget test", (tester) async {});
}
